4 ms·
You can certainly operate directly on pixel arrays as well. When the original example here is changed to operate on .Pix instead of using .At(), it runs about 2
by hunterloftis 7y ago
You can certainly operate directly on pixel arrays as well. When the original example here is changed to operate on .Pix instead of using .At(), it runs about 2x faster:
https://github.com/nicolashahn/diffimg-go/pull/2 https://github.com/nicolashahn/diffimg-go/pull/2